# 🔢 AxiomX

**AxiomX** is a lightweight, pure-Python mathematical library built from
first principles --- designed for accuracy, learning, and mathematical
exploration.

------------------------------------------------------------------------

## 📢 Community

Join Discord for updates and feature requests. Join [here](https://discord.gg/CrEf8mDB).

------------------------------------------------------------------------

## 🚀 Features

### 📐 Core Mathematics

-   Constants (π, e, φ, √2, γ, ...)
-   Custom implementations

### 📈 Exponential & Logarithmic

-   exp(x)
-   ln(x)
-   log10(x)
-   log2(x)
-   log(arg, base)

### 📐 Trigonometry

-   sin, cos, tan, cot, sec, cosec
-   inverse functions

### 🔢 Hyperbolic Functions

-   sinh, cosh, tanh, coth

### 🧮 General Functions

-   absolute(x)
-   sqrt(x)
-   gamma(x)
-   cbrt(x)
-   zeta(n) and beta(n)

### ∫ Calculus

-   Numerical integration
-   summation
-   convergence analysis
-   limit evaluation

------------------------------------------------------------------------

## 🧱 Matrix Engine (NEW)

-   Matrix creation
-   A\[i, j\] access
-   Addition, subtraction, multiplication by using actual mathematical operators.
-   Transpose
-   Determinant
-   Inverse
-   Division (via inverse) by using / operator

If you want to create a zero matrix or identity of any order, you can do it this way:

```
from AxiomX.matrix import Matrix

a = Matrix(x,y) # you can put your values in place of x and y.
a.zero() # for zero matrix
a.identity() # for identity matrix.
```

If you want to create a matrix, from a list, you can try it this way:

```
from AxiomX.matrix import Matrix

a = Matrix.from_list([]) # enter your matrix in it.
```
------------------------------------------------------------------------

## 📦 Installation

`pip install axiomx`

------------------------------------------------------------------------

## ▶️ Usage
```
from AxiomX.matrix import Matrix

A = Matrix.from_list(\[\[1, 2\], \[3, 4\]\]) print(A.det())
```

------------------------------------------------------------------------

## 🧠 Philosophy

Accuracy \> Speed

------------------------------------------------------------------------

## 🌐 Website

https://axiomxpy.wordpress.com

------------------------------------------------------------------------

## 🛣️ Roadmap

-   Advanced linear algebra
-   Series & constants

------------------------------------------------------------------------

## 📜 License

MIT License
